:orphan:

Usage Guide
===========

Usage examples:

.. note::
   :code:`print()` statements in the examples below are only so these docs render at this site. They are not required for actual usage.

   Sometimes using ``pymer4`` interactively can cause the Python kernel to crash. This is more likely to happen if you have multiple interactive sessions running simulatenously. One way around this is to put this at the top of your notebook/code:

   .. code-block:: python

       import os
       os.environ['KMP_DUPLICATE_LIB_OK']='True'



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="1. Basic Usage Guide">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_example_01_basic_usage_thumb.png
    :alt: 1. Basic Usage Guide

  :ref:`sphx_glr_auto_examples_example_01_basic_usage.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">1. Basic Usage Guide</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="2. Categorical Predictors">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_example_02_categorical_thumb.png
    :alt: 2. Categorical Predictors

  :ref:`sphx_glr_auto_examples_example_02_categorical.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">2. Categorical Predictors</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="3. ANOVA tables and post-hoc comparisons">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_example_03_posthoc_thumb.png
    :alt: 3. ANOVA tables and post-hoc comparisons

  :ref:`sphx_glr_auto_examples_example_03_posthoc.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">3. ANOVA tables and post-hoc comparisons</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="pymer4 gives you a lot of control over what you want your data to look like by setting properti...">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_example_04_simulating_data_thumb.png
    :alt: 4. Simulating Data

  :ref:`sphx_glr_auto_examples_example_04_simulating_data.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">4. Simulating Data</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="5. Additional Statistics Functions">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_example_05_misc_stats_thumb.png
    :alt: 5. Additional Statistics Functions

  :ref:`sphx_glr_auto_examples_example_05_misc_stats.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">5. Additional Statistics Functions</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/example_01_basic_usage
   /auto_examples/example_02_categorical
   /auto_examples/example_03_posthoc
   /auto_examples/example_04_simulating_data
   /auto_examples/example_05_misc_stats


.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-gallery

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download all examples in Python source code: auto_examples_python.zip </auto_examples/auto_examples_python.zip>`

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip </auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
